package CMS::Drupal::Admin;
$CMS::Drupal::Admin::VERSION = '0.93';
# ABSTRACT: Provides the namespace for CMS::Drupal::Admin::* packages.

use strict;

# nothing here

1; #return true

__END__

=pod

=encoding UTF-8

=head1 NAME

CMS::Drupal::Admin - Provides the namespace for CMS::Drupal::Admin::* packages.

=head1 VERSION

version 0.93

=head1 SYNOPSIS

This an empty package.

=head1 DESCRIPTION

This is an empty package that only exists to provide the namespace for
CMS::Drupal::Admin::* packages.

Authors wishing to contribute packages for interacting administratively
with a Drupal installation should create them under this namespace.

=head1 AUTHOR

Nick Tonkin <tonkin@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by Nick Tonkin.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
